@@ -1,5 +1,5 @@
 /*
- * $Id: MessageProcessors.java 20320 2010-11-24 15:03:31Z dfeist $
+ * $Id: MessageProcessors.java 21060 2011-01-21 19:26:13Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -25,6 +25,6 @@ public class MessageProcessors
 
     public static MessageProcessorChain singletonChain(MessageProcessor mp)
     {
-        return new DefaultMessageProcessorChain(mp);
+        return DefaultMessageProcessorChain.from(mp);
     }
 }
