@@ -1,5 +1,5 @@
 /*
- * $Id: UnauthorisedException.java 19739 2010-09-27 14:28:40Z tcarlson $
+ * $Id: UnauthorisedException.java 21257 2011-02-11 22:43:40Z dandiep $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -47,14 +47,20 @@ public class UnauthorisedException extends SecurityException
         super(message, event, cause);
     }
 
+    public UnauthorisedException(MuleEvent event, SecurityContext context, SecurityFilter filter)
+    {
+        super(constructMessage(context, event.getEndpoint(), filter), event);
+    }
+
+    @Deprecated
     public UnauthorisedException(MuleEvent event, SecurityContext context, 
-        ImmutableEndpoint endpoint, EndpointSecurityFilter filter)
+        ImmutableEndpoint endpoint, SecurityFilter filter)
     {
         super(constructMessage(context, endpoint, filter), event);
     }
 
     private static Message constructMessage(SecurityContext context, ImmutableEndpoint endpoint,
-        EndpointSecurityFilter filter)
+                                            SecurityFilter filter)
     {
 
         Message m;
