@@ -1,5 +1,5 @@
 /*
- * $Id: CoreMessages.java 20267 2010-11-19 03:15:43Z dfeist $
+ * $Id: CoreMessages.java 21257 2011-02-11 22:43:40Z dandiep $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -1333,4 +1333,9 @@ public class CoreMessages extends MessageFactory
         return factory.createMessage(BUNDLE_PATH, 330, key);
     }
 
+    public static Message authorizationDeniedOnEndpoint(EndpointURI endpointURI)
+    {
+        return factory.createMessage(BUNDLE_PATH, 332, endpointURI);
+    }
+
 }
