@@ -1,5 +1,5 @@
 /*
- * $Id: Validator.java 20320 2010-11-24 15:03:31Z dfeist $
+ * $Id: Validator.java 20759 2010-12-15 23:30:56Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -230,7 +230,7 @@ public class Validator extends AbstractFlowConstruct
          */
         public MuleEvent process(MuleEvent event) throws MuleException
         {
-            final MuleEvent result = RequestContext.cloneAndUpdateEventEndpoint(event, this);
+            final MuleEvent result = RequestContext.setEvent(event);
 
             try
             {
