@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultInboundEndpoint.java 20721 2010-12-14 19:39:43Z tcarlson $
+ * $Id: DefaultInboundEndpoint.java 21286 2011-02-15 20:09:25Z dzapata $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -30,6 +30,7 @@ import org.mule.api.transaction.TransactionConfig;
 import org.mule.api.transport.Connector;
 import org.mule.config.MuleManifest;
 import org.mule.config.i18n.CoreMessages;
+import org.mule.transport.ConnectException;
 import org.mule.transport.polling.MessageProcessorPollingMessageReceiver;
 
 import java.beans.ExceptionListener;
@@ -105,6 +106,11 @@ public class DefaultInboundEndpoint extends AbstractEndpoint implements InboundE
                  ((Startable)polledMp).start();
             }
         }
+        // Let connection exceptions bubble up to trigger the reconnection strategy.
+        catch (ConnectException ce)
+        {
+            throw ce;
+        }
         catch (Exception e)
         {
             throw new LifecycleException(CoreMessages.failedToStartInboundEndpoint(this), e, this);
