@@ -1,5 +1,5 @@
 /*
- * $Id: MessageEnricher.java 20555 2010-12-09 17:54:31Z aperepel $
+ * $Id: MessageEnricher.java 20759 2010-12-15 23:30:56Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSource, Inc.  All rights reserved.  http://www.mulesource.com
  *
@@ -33,8 +33,8 @@ public class MessageEnricher extends AbstractMessageProcessorOwner implements Me
     public MuleEvent process(MuleEvent event) throws MuleException
     {
         ExpressionManager expressionManager = event.getMuleContext().getExpressionManager();
-        MuleMessage enrichmentMessage = enrichmentProcessor.process(
-            RequestContext.cloneAndUpdateEventEndpoint(event, enrichmentProcessor)).getMessage();
+        MuleMessage enrichmentMessage = enrichmentProcessor.process(RequestContext.setEvent(event))
+            .getMessage();
 
         if (enrichmentMessage != null)
         {
