@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractLifecycleManager.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: AbstractLifecycleManager.java 21286 2011-02-15 20:09:25Z dzapata $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -9,6 +9,7 @@
  */
 package org.mule.lifecycle;
 
+import org.mule.api.MuleContext;
 import org.mule.api.lifecycle.Disposable;
 import org.mule.api.lifecycle.Initialisable;
 import org.mule.api.lifecycle.LifecycleCallback;
@@ -18,6 +19,8 @@ import org.mule.api.lifecycle.LifecycleState;
 import org.mule.api.lifecycle.Startable;
 import org.mule.api.lifecycle.Stoppable;
 import org.mule.lifecycle.phases.NotInLifecyclePhase;
+import org.mule.transport.AbstractConnector;
+import org.mule.transport.ConnectException;
 
 import java.util.HashSet;
 import java.util.LinkedHashSet;
@@ -28,16 +31,16 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 /**
- * This is a base implementation of the {@link org.mule.api.lifecycle.LifecycleManager} interface and provides
- * almost all the plumbing required to write a {@link org.mule.api.lifecycle.LifecycleManager} implementation.  This
- * class handles the tracking ofg the phases, transition validation and checking state.
+ * This is a base implementation of the {@link org.mule.api.lifecycle.LifecycleManager} interface
+ * and provides almost all the plumbing required to write a {@link org.mule.api.lifecycle.LifecycleManager}
+ * implementation. This class handles the tracking ofg the phases, transition validation and
+ * checking state.
  *
  * @param <O> The object type being managed by this {@link org.mule.api.lifecycle.LifecycleManager}
  * @since 3.0
  */
 public abstract class AbstractLifecycleManager<O> implements LifecycleManager
 {
-
     /**
      * logger used by this class
      */
@@ -54,7 +57,6 @@ public abstract class AbstractLifecycleManager<O> implements LifecycleManager
 
     private TreeMap<String, LifecycleCallback> callbacks = new TreeMap<String, LifecycleCallback>();
 
-
     public AbstractLifecycleManager(String id, O object)
     {
         lifecycleManagerId = id;
@@ -139,9 +141,15 @@ public abstract class AbstractLifecycleManager<O> implements LifecycleManager
             callback.onTransition(phase, object);
             setCurrentPhase(phase);
         }
-        catch (LifecycleException e)
+        // In the case of a connection exception, trigger the reconnection strategy.
+        catch (ConnectException ce)
         {
-            throw e;
+            MuleContext muleContext = ((AbstractConnector) ce.getFailed()).getMuleContext();
+            muleContext.getExceptionListener().handleException(ce);
+        }
+        catch (LifecycleException le)
+        {
+            throw le;
         }
         catch (Exception e)
         {
@@ -203,9 +211,9 @@ public abstract class AbstractLifecycleManager<O> implements LifecycleManager
      * state from the 'completedPhases' collection once a transition occurs. This is only necessary for a Lifecycle
      * Manager that introduces a new phase pair.
      *
-     * @param currentPhase the currently completed phase
+     * @param phase the currently completed phase
      */
-    protected void notifyTransition(String currentPhase)
+    protected void notifyTransition(String phase)
     {
         //do nothing
     }
@@ -227,6 +235,4 @@ public abstract class AbstractLifecycleManager<O> implements LifecycleManager
     {
         return state;
     }
-
-
 }
