@@ -1,5 +1,5 @@
 /*
- * $Id: DefaultLifecycleState.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: DefaultLifecycleState.java 21050 2011-01-20 17:53:08Z aperepel $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -40,7 +40,7 @@ public class DefaultLifecycleState implements LifecycleState
 
     public boolean isStarted()
     {
-        return lifecycleManager.isPhaseComplete(Startable.PHASE_NAME);
+        return Startable.PHASE_NAME.equals(lifecycleManager.getCurrentPhase());
     }
 
     public boolean isStarting()
@@ -50,7 +50,7 @@ public class DefaultLifecycleState implements LifecycleState
 
     public boolean isStopped()
     {
-        return lifecycleManager.isPhaseComplete(Stoppable.PHASE_NAME);
+        return Stoppable.PHASE_NAME.equals(lifecycleManager.getCurrentPhase());
     }
 
     public boolean isStopping()
