@@ -1,5 +1,5 @@
 /*
- * $Id: SedaService.java 20088 2010-11-05 16:51:41Z aperepel $
+ * $Id: SedaService.java 21233 2011-02-10 04:37:56Z dzapata $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -12,28 +12,25 @@ package org.mule.model.seda;
 
 import org.mule.api.MuleContext;
 import org.mule.api.MuleException;
-import org.mule.api.config.MuleConfiguration;
 import org.mule.api.config.ThreadingProfile;
-import org.mule.api.context.WorkManager;
-import org.mule.api.context.WorkManagerSource;
 import org.mule.api.lifecycle.InitialisationException;
-import org.mule.api.lifecycle.LifecycleException;
 import org.mule.api.processor.MessageProcessor;
+import org.mule.api.processor.MessageProcessorChainBuilder;
 import org.mule.config.ChainedThreadingProfile;
 import org.mule.config.QueueProfile;
 import org.mule.config.i18n.CoreMessages;
 import org.mule.config.i18n.MessageFactory;
+import org.mule.interceptor.ProcessingTimeInterceptor;
 import org.mule.lifecycle.processor.ProcessIfStartedWaitIfSyncPausedMessageProcessor;
 import org.mule.management.stats.ServiceStatistics;
 import org.mule.processor.SedaStageInterceptingMessageProcessor;
-import org.mule.processor.builder.InterceptingChainMessageProcessorBuilder;
 import org.mule.service.AbstractService;
 import org.mule.service.processor.ServiceInternalMessageProcessor;
-import org.mule.service.processor.ServiceLoggingMessageObserver;
+import org.mule.service.processor.ServiceLoggingMessageProcessor;
 import org.mule.service.processor.ServiceOutboundMessageProcessor;
-import org.mule.service.processor.ServiceOutboundStatisticsObserver;
-import org.mule.service.processor.ServiceSetEventRequestContextMessageObserver;
-import org.mule.service.processor.ServiceStatisticsMessageObserver;
+import org.mule.service.processor.ServiceOutboundStatisticsMessageProcessor;
+import org.mule.service.processor.ServiceSetEventRequestContextMessageProcessor;
+import org.mule.service.processor.ServiceStatisticsMessageProcessor;
 
 /**
  * A Seda service runs inside a Seda Model and is responsible for managing a Seda
@@ -64,7 +61,7 @@ public class SedaService extends AbstractService
      */
     protected QueueProfile queueProfile;
 
-    protected WorkManager workManager;
+    protected SedaStageInterceptingMessageProcessor sedaStage;
 
     public SedaService(MuleContext muleContext)
     {
@@ -77,21 +74,17 @@ public class SedaService extends AbstractService
         return new ProcessIfStartedWaitIfSyncPausedMessageProcessor(this, lifecycleManager.getState());
     }
 
-    protected void addMessageProcessors(InterceptingChainMessageProcessorBuilder builder)
+    protected void addMessageProcessors(MessageProcessorChainBuilder builder)
     {
-        builder.chain(new ServiceLoggingMessageObserver(this));
-        builder.chain(new ServiceStatisticsMessageObserver(this));
-        builder.chain(new ServiceSetEventRequestContextMessageObserver());
+        builder.chain(new ProcessingTimeInterceptor(null, this));
+        builder.chain(new ServiceLoggingMessageProcessor(this));
+        builder.chain(new ServiceStatisticsMessageProcessor(this));
+        builder.chain(new ServiceSetEventRequestContextMessageProcessor());
         if (getThreadingProfile().isDoThreading())
         {
-            builder.chain(new SedaStageInterceptingMessageProcessor(getName(), queueProfile, queueTimeout,
-                new WorkManagerSource()
-                {
-                    public WorkManager getWorkManager() throws MuleException
-                    {
-                        return workManager;
-                    }
-                }, lifecycleManager.getState(), stats, muleContext));
+            sedaStage = new SedaStageInterceptingMessageProcessor(getName(), queueProfile, queueTimeout,
+                threadingProfile, stats, muleContext);
+            builder.chain(sedaStage);
         }
         builder.chain(new ServiceInternalMessageProcessor(this));
         if (asyncReplyMessageSource.getEndpoints().size() > 0)
@@ -99,7 +92,7 @@ public class SedaService extends AbstractService
             builder.chain(createAsyncReplyProcessor());
         }
         builder.chain(new ServiceOutboundMessageProcessor(this));
-        builder.chain(new ServiceOutboundStatisticsObserver(this));
+        builder.chain(new ServiceOutboundStatisticsMessageProcessor(this));
         builder.chain(outboundRouter);
     }
 
@@ -126,13 +119,6 @@ public class SedaService extends AbstractService
         // TODO it would be nicer if the shutdown value was encapsulated in the
         // Threading profile, but it is more difficult than it seems
 
-        final MuleConfiguration config = muleContext.getConfiguration();
-        final boolean containerMode = config.isContainerMode();
-        final String threadPrefix = containerMode
-                ? String.format("[%s].%s", config.getId(), getName())
-                : getName();
-        workManager = threadingProfile.createWorkManager(threadPrefix, config.getShutdownTimeout());
-
         if (queueProfile == null && model != null)
         {
             queueProfile = ((SedaModel) model).getQueueProfile();
@@ -141,7 +127,7 @@ public class SedaService extends AbstractService
         {
             setQueueTimeout(((SedaModel) model).getQueueTimeout());
         }
-
+        
         try
         {
             if (name == null)
@@ -157,43 +143,6 @@ public class SedaService extends AbstractService
         super.doInitialise();
     }
 
-    @Override
-    protected void doStart() throws MuleException
-    {
-        try
-        {
-            workManager.start();
-        }
-        catch (Exception e)
-        {
-            throw new LifecycleException(CoreMessages.failedToStart("Service: " + getName()), e, this);
-        }
-        super.doStart();
-    }
-
-    @Override
-    protected void doStop() throws MuleException
-    {
-        super.doStop();
-        workManager.dispose();
-    }
-
-    @Override
-    protected void doForceStop() throws MuleException
-    {
-        doStop();
-    }
-
-    @Override
-    protected void doDispose()
-    {
-        super.doDispose();
-        if (workManager != null)
-        {
-            workManager.dispose();
-        }
-    }
-
     @Override
     protected ServiceStatistics createStatistics()
     {
@@ -230,4 +179,18 @@ public class SedaService extends AbstractService
         this.threadingProfile = threadingProfile;
     }
 
+    @Override
+    protected void doPause() throws MuleException
+    {
+        super.doPause();
+        sedaStage.pause();
+    }
+
+    @Override
+    protected void doResume() throws MuleException
+    {
+        sedaStage.resume();
+        super.doResume();
+    }
+
 }
