@@ -1,5 +1,5 @@
 /*
- * $Id: RemoteDispatcherComponent.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: RemoteDispatcherComponent.java 21218 2011-02-09 19:59:05Z mike.schilling $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -22,6 +22,7 @@ import org.mule.api.MuleException;
 import org.mule.api.MuleMessage;
 import org.mule.api.MuleSession;
 import org.mule.api.config.MuleProperties;
+import org.mule.api.construct.FlowConstruct;
 import org.mule.api.endpoint.EndpointBuilder;
 import org.mule.api.endpoint.EndpointFactory;
 import org.mule.api.endpoint.ImmutableEndpoint;
@@ -40,6 +41,7 @@ import org.mule.config.i18n.CoreMessages;
 import org.mule.endpoint.EndpointURIEndpointBuilder;
 import org.mule.message.DefaultExceptionPayload;
 import org.mule.model.seda.SedaService;
+import org.mule.module.client.i18n.ClientMessages;
 import org.mule.module.client.remoting.notification.RemoteDispatcherNotification;
 import org.mule.object.PrototypeObjectFactory;
 import org.mule.session.DefaultMuleSession;
@@ -96,7 +98,8 @@ public class RemoteDispatcherComponent implements Callable, Initialisable
     public Object onCall(MuleEventContext context) throws Exception
     {
         muleContext = context.getMuleContext();
-        if(context.transformMessageToString().equals(ServerHandshake.SERVER_HANDSHAKE_PROPERTY))
+        byte[] messageBytes = (byte[]) context.transformMessage(byte[].class);
+        if(new String(messageBytes).equals(ServerHandshake.SERVER_HANDSHAKE_PROPERTY))
         {
             return doHandshake(context);
         }
@@ -159,8 +162,13 @@ public class RemoteDispatcherComponent implements Callable, Initialisable
 
         if (destComponent != null)
         {
-            Service service = muleContext.getRegistry().lookupService(destComponent);
-            MuleSession session = new DefaultMuleSession(service, muleContext);
+            Object fc = muleContext.getRegistry().lookupObject(destComponent);
+            if (!(fc instanceof FlowConstruct))
+            {
+                return handleException(null, new DefaultMuleException(ClientMessages.noSuchFlowConstruct(destComponent)));
+            }
+            FlowConstruct flowConstruct = (FlowConstruct) fc;
+            MuleSession session = new DefaultMuleSession(flowConstruct, muleContext);
             // Need to do this otherise when the event is invoked the
             // transformer associated with the Mule Admin queue will be invoked, but
             // the message will not be of expected type
@@ -168,21 +176,28 @@ public class RemoteDispatcherComponent implements Callable, Initialisable
             EndpointBuilder builder = new EndpointURIEndpointBuilder(RequestContext.getEvent().getEndpoint());
             // TODO - is this correct? it stops any other transformer from being set
             builder.setTransformers(new LinkedList());
-            ImmutableEndpoint ep = muleContext.getRegistry().lookupEndpointFactory().getInboundEndpoint(builder);
+            ImmutableEndpoint ep = muleContext.getEndpointFactory().getInboundEndpoint(builder);
             MuleEvent event = new DefaultMuleEvent(action.getMessage(), ep, context.getSession());
             event = RequestContext.setEvent(event);
 
             if (context.getExchangePattern().hasResponse())
             {
-                MuleEvent resultEvent = service.sendEvent(event);
+                MuleEvent resultEvent = flowConstruct.getMessageProcessorChain().process(event);
                 result = resultEvent == null ? null : resultEvent.getMessage();
-                ByteArrayOutputStream out = new ByteArrayOutputStream();
-                wireFormat.write(out, result, getEncoding());
-                return out.toByteArray();
+                if (result == null)
+                {
+                    return null;
+                }
+                else
+                {
+                    ByteArrayOutputStream out = new ByteArrayOutputStream();
+                    wireFormat.write(out, result, getEncoding());
+                    return out.toByteArray();
+                }
             }
             else
             {
-                service.dispatchEvent(event);
+                flowConstruct.getMessageProcessorChain().process(event);
                 return null;
             }
         }
@@ -202,7 +217,7 @@ public class RemoteDispatcherComponent implements Callable, Initialisable
         {
             if (RemoteDispatcherNotification.ACTION_DISPATCH == action.getAction())
             {
-                endpoint = managementContext.getRegistry().lookupEndpointFactory().getOutboundEndpoint(
+                endpoint = managementContext.getEndpointFactory().getOutboundEndpoint(
                     action.getResourceIdentifier());
                 context.dispatchEvent(action.getMessage(), endpoint);
                 return null;
@@ -212,7 +227,7 @@ public class RemoteDispatcherComponent implements Callable, Initialisable
                 EndpointFactory endpointFactory = managementContext.getRegistry().lookupEndpointFactory();
                 EndpointBuilder endpointBuilder = endpointFactory.getEndpointBuilder(action.getResourceIdentifier());
                 endpointBuilder.setExchangePattern(MessageExchangePattern.REQUEST_RESPONSE);
-                endpoint = managementContext.getRegistry().lookupEndpointFactory().getOutboundEndpoint(endpointBuilder);
+                endpoint = managementContext.getEndpointFactory().getOutboundEndpoint(endpointBuilder);
                 result = context.sendEvent(action.getMessage(), endpoint);
                 if (result == null)
                 {
@@ -287,7 +302,9 @@ public class RemoteDispatcherComponent implements Callable, Initialisable
             props.put("wireFormat", wireFormat);
             props.put("encoding", encoding);
             props.put("synchronousEventTimeout", new Integer(eventTimeout));
-            service.setComponent(new SimpleCallableJavaComponent(new PrototypeObjectFactory(RemoteDispatcherComponent.class, props)));
+            final SimpleCallableJavaComponent component = new SimpleCallableJavaComponent(new PrototypeObjectFactory(RemoteDispatcherComponent.class, props));
+            component.setMuleContext(muleContext);
+            service.setComponent(component);
 
 
             if (!(service.getMessageSource() instanceof CompositeMessageSource))
