@@ -1,5 +1,5 @@
 /*
- * $Id: DatabindingTestCase.java 20320 2010-11-24 15:03:31Z dfeist $
+ * $Id: DatabindingTestCase.java 21151 2011-01-31 21:53:23Z dzapata $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,16 +11,18 @@
 package org.mule.module.cxf;
 
 import org.mule.api.MuleMessage;
+import org.mule.api.endpoint.InboundEndpoint;
 import org.mule.module.client.MuleClient;
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.DynamicPortTestCase;
 
-public class DatabindingTestCase extends FunctionalTestCase
+public class DatabindingTestCase extends DynamicPortTestCase
 {
 
     public void testEchoWsdl() throws Exception
     {
         MuleClient client = new MuleClient(muleContext);
-        MuleMessage result = client.request("http://localhost:63081/services/Echo?wsdl", 5000);
+        MuleMessage result = client.request(((InboundEndpoint) client.getMuleContext().getRegistry()
+                        .lookupObject("httpInbound")).getAddress() + "?wsdl", 5000);
         assertNotNull(result.getPayload());
     }
 
@@ -29,4 +31,10 @@ public class DatabindingTestCase extends FunctionalTestCase
         return "databinding-conf.xml";
     }
 
+    @Override
+    protected int getNumPortsToFind()
+    {
+        return 1;
+    }
+
 }
