@@ -1,5 +1,5 @@
 /*
- * $Id: MtomClientTestCase.java 20320 2010-11-24 15:03:31Z dfeist $
+ * $Id: MtomClientTestCase.java 21151 2011-01-31 21:53:23Z dzapata $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,9 +10,9 @@
 
 package org.mule.module.cxf.employee;
 
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.DynamicPortTestCase;
 
-public class MtomClientTestCase extends FunctionalTestCase
+public class MtomClientTestCase extends DynamicPortTestCase
 {
 
     public void testEchoService() throws Exception
@@ -36,5 +36,11 @@ public class MtomClientTestCase extends FunctionalTestCase
         return "mtom-client-conf.xml";
     }
 
+    @Override
+    protected int getNumPortsToFind()
+    {
+        return 1;
+    }
+
 }
 
