@@ -1,5 +1,5 @@
 /*
- * $Id: EndpointBindsToCorrectWdslPortTestCase.java 20320 2010-11-24 15:03:31Z dfeist $
+ * $Id: EndpointBindsToCorrectWdslPortTestCase.java 21151 2011-01-31 21:53:23Z dzapata $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -17,6 +17,7 @@ import org.mule.endpoint.DefaultInboundEndpoint;
 import org.mule.module.cxf.CxfInboundMessageProcessor;
 import org.mule.module.cxf.config.FlowConfiguringMessageProcessor;
 import org.mule.service.ServiceCompositeMessageSource;
+import org.mule.tck.DynamicPortTestCase;
 import org.mule.tck.FunctionalTestCase;
 
 import java.util.List;
@@ -24,7 +25,7 @@ import java.util.List;
 import org.apache.cxf.endpoint.Server;
 import org.apache.cxf.service.model.EndpointInfo;
 
-public class EndpointBindsToCorrectWdslPortTestCase extends FunctionalTestCase
+public class EndpointBindsToCorrectWdslPortTestCase extends DynamicPortTestCase
 {
 
     @Override
@@ -50,4 +51,10 @@ public class EndpointBindsToCorrectWdslPortTestCase extends FunctionalTestCase
             "The local part of the endpoing name must be the one supplied as the endpointName parameter on the cxf:inbound-endpoint",
             "ListsSoap", endpointInfo.getName().getLocalPart());
     }
+
+    @Override
+    protected int getNumPortsToFind()
+    {
+        return 1;
+    }
 }
