@@ -1,5 +1,5 @@
 /*
- * $Id: MuleMessageService.java 19770 2010-09-29 18:17:54Z tcarlson $
+ * $Id: MuleMessageService.java 20811 2010-12-21 10:20:20Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -13,11 +13,13 @@ package org.mule.module.jbpm;
 import org.mule.MessageExchangePattern;
 import org.mule.api.MuleMessage;
 import org.mule.module.bpm.MessageService;
+import org.mule.module.bpm.ProcessComponent;
 
 import java.util.Map;
 
 /**
- * Proxy for the message-generation service provided by Mule.  The real service gets injected here by the {@link ProcessComponent}.
+ * Proxy for the message-generation service provided by Mule. The real service gets
+ * injected here by the {@link ProcessComponent}.
  */
 public class MuleMessageService implements MessageService
 {
