@@ -1,5 +1,5 @@
 /*
- * $Id: WrapperManagerAgent.java 19747 2010-09-28 03:24:32Z dirk.olmes $
+ * $Id: WrapperManagerAgent.java 20847 2010-12-29 20:17:22Z aperepel $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -29,7 +29,6 @@ import javax.management.MalformedObjectNameException;
 import javax.management.ObjectName;
 
 import edu.emory.mathcs.backport.java.util.concurrent.atomic.AtomicReference;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.tanukisoftware.wrapper.WrapperSystemPropertyUtil;
@@ -203,9 +202,9 @@ public class WrapperManagerAgent extends AbstractAgent
      * not present in the {@link WrapperManagerMBean} until version 3.2.3.
      * SpringSource's TC Server uses The wrapper version 3.2.0 so having this method
      * here allows us to be compatible with TC Server.
-     * 
+     *
      * @return The PID of the Java process.
-     * @see http://www.mulesoft.org/jira/browse/MULE-5106
+     * @see <a href="http://www.mulesoft.org/jira/browse/MULE-5106">MULE-5106</a>
      */
     public static int getJavaPID()
     {
@@ -224,9 +223,9 @@ public class WrapperManagerAgent extends AbstractAgent
      * is not present in the {@link WrapperManagerMBean} until version 3.2.3.
      * SpringSource's TC Server uses The wrapper version 3.2.0 so having this method
      * here allows us to be compatible with TC Server.
-     * 
+     *
      * @return The PID of the Wrapper process.
-     * @see http://www.mulesoft.org/jira/browse/MULE-5106
+     * @see <a href="http://www.mulesoft.org/jira/browse/MULE-5106">MULE-5106</a>
      */
     public static int getWrapperPID()
     {
@@ -239,7 +238,8 @@ public class WrapperManagerAgent extends AbstractAgent
         return WrapperSystemPropertyUtil.getIntProperty("wrapper.pid", 0);
     }
 
-    protected void lazyInitWrapperManager() {
+    protected void lazyInitWrapperManager()
+    {
         WrapperManagerMBean wm = (WrapperManagerMBean) wrapperManagerRef.get();
 
         if (wm != null)
@@ -255,7 +255,8 @@ public class WrapperManagerAgent extends AbstractAgent
      * Unregister all MBeans if there are any left over the old deployment
      */
     protected void unregisterMBeansIfNecessary()
-        throws MalformedObjectNameException, InstanceNotFoundException, MBeanRegistrationException {
+            throws MalformedObjectNameException, InstanceNotFoundException, MBeanRegistrationException
+    {
         if (mBeanServer == null || wrapperName == null)
         {
             return;
@@ -266,19 +267,4 @@ public class WrapperManagerAgent extends AbstractAgent
         }
     }
 
-    /**
-     * Quietly unregister ourselves.
-     */
-    protected void unregisterMeQuietly()
-    {
-        try
-        {
-            // remove the agent from the list, it's not functional
-            muleContext.getRegistry().unregisterAgent(this.getName());
-        }
-        catch (MuleException e)
-        {
-            // not interested, really
-        }
-    }
 }
