@@ -1,5 +1,5 @@
 /*
- * $Id: StatisticsService.java 20288 2010-11-22 01:19:54Z mike.schilling $
+ * $Id: StatisticsService.java 20811 2010-12-21 10:20:20Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -55,25 +55,16 @@ public class StatisticsService implements StatisticsServiceMBean
 
     }
 
-    /**
-     * @see org.mule.api.management.stats.Statistics#clear()
-     */
     public void clear()
     {
         stats.clear();
     }
 
-    /**
-     * @see org.mule.api.management.stats.Statistics#isEnabled()
-     */
     public boolean isEnabled()
     {
         return stats.isEnabled();
     }
 
-    /**
-     * @see org.mule.api.management.stats.Statistics#setEnabled(boolean)
-     */
     public void setEnabled(boolean b)
     {
         stats.setEnabled(b);
@@ -84,7 +75,7 @@ public class StatisticsService implements StatisticsServiceMBean
      * @deprecated use #getServiceStatistics
      */
     @Deprecated
-    public Collection getComponentStatistics()
+    public Collection<?> getComponentStatistics()
     {
         return stats.getServiceStatistics();
     }
@@ -123,5 +114,4 @@ public class StatisticsService implements StatisticsServiceMBean
         stats.logSummary(printer);
         return w.toString();
     }
-
 }
