@@ -1,5 +1,5 @@
 /*
- * $Id: MuleContainerSystemClassLoader.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: MuleContainerSystemClassLoader.java 20208 2010-11-17 14:33:40Z dirk.olmes $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -22,20 +22,22 @@ import org.apache.commons.logging.LogFactory;
  */
 public class MuleContainerSystemClassLoader extends URLClassLoader
 {
-
     protected transient Log logger = LogFactory.getLog(getClass());
 
-    public MuleContainerSystemClassLoader()
+    public MuleContainerSystemClassLoader(DefaultMuleClassPathConfig classPath)
     {
         super(new URL[0]);
+
         try
         {
-            DefaultMuleClassPathConfig classPath = new DefaultMuleClassPathConfig(MuleContainerBootstrap.lookupMuleHome(),
-                                                                                  MuleContainerBootstrap.lookupMuleBase());
-            @SuppressWarnings("unchecked")
             final List<URL> urlsList = classPath.getURLs();
             for (URL url : urlsList)
             {
+                if (logger.isDebugEnabled())
+                {
+                    logger.debug("adding URL " + url);
+                }
+
                 addURL(url);
             }
         }
