@@ -1,5 +1,5 @@
 /*
- * $Id: SpringSecurityMessages.java 20320 2010-11-24 15:03:31Z dfeist $
+ * $Id: SpringSecurityMessages.java 21257 2011-02-11 22:43:40Z dandiep $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -28,6 +28,16 @@ public class SpringSecurityMessages extends MessageFactory
     {
         return factory.createMessage(BUNDLE_PATH, 2);
     }
+
+    public static Message noGrantedAuthority(String authority)
+    {
+        return factory.createMessage(BUNDLE_PATH, 3, authority);
+    }
+
+    public static Message springAuthenticationRequired()
+    {
+        return factory.createMessage(BUNDLE_PATH, 4);
+    }
 }
 
 
