@@ -1,5 +1,5 @@
 /*
- * $Id$
+ * $Id: DefaultRegistryBroker.java 21417 2011-03-02 18:54:39Z dzapata $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -11,7 +11,6 @@
 package org.mule.registry;
 
 import org.mule.api.MuleContext;
-import org.mule.api.lifecycle.LifecycleException;
 import org.mule.api.registry.Registry;
 
 import java.util.ArrayList;
@@ -25,6 +24,7 @@ public class DefaultRegistryBroker extends AbstractRegistryBroker
 
     public DefaultRegistryBroker(MuleContext context)
     {
+        super(context);
         transientRegistry = new TransientRegistry(context);
         registries.add(0, transientRegistry);
     }
