@@ -1,5 +1,5 @@
 /*
- * $Id: StartableCompositeMessageSourceTestCase.java 20320 2010-11-24 15:03:31Z dfeist $
+ * $Id: StartableCompositeMessageSourceTestCase.java 21400 2011-03-01 19:21:27Z dzapata $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -53,7 +53,14 @@ public class StartableCompositeMessageSourceTestCase extends AbstractMuleTestCas
         assertNull(listener.event);
 
         source.start();
-        source.triggerSource();
+        try
+        {
+            source.triggerSource();
+            fail("Exception expected");
+        }
+        catch (Exception e)
+        {
+        }
         assertNull(listener.event);
 
         compositeSource.start();
