@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractConnector.java 20531 2010-12-08 21:34:21Z dzapata $
+ * $Id: AbstractConnector.java 21285 2011-02-15 18:49:41Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -95,6 +95,7 @@ import edu.emory.mathcs.backport.java.util.concurrent.ThreadFactory;
 import edu.emory.mathcs.backport.java.util.concurrent.TimeUnit;
 import edu.emory.mathcs.backport.java.util.concurrent.atomic.AtomicBoolean;
 import edu.emory.mathcs.backport.java.util.concurrent.atomic.AtomicReference;
+
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.commons.pool.KeyedPoolableObjectFactory;
@@ -262,7 +263,10 @@ public abstract class AbstractConnector implements Connector, WorkListener
     protected ConnectorLifecycleManager lifecycleManager;
 
     // TODO connect and disconnect are not part of lifecycle management right now
-    protected AtomicBoolean connected = new AtomicBoolean(false);
+    private AtomicBoolean connected = new AtomicBoolean(false);
+
+    /** Is this connector currently undergoing a reconnection strategy? */
+    private AtomicBoolean reconnecting = new AtomicBoolean(false);
 
     /**
      * Indicates whether the connector should start upon connecting. This is
@@ -396,6 +400,7 @@ public abstract class AbstractConnector implements Connector, WorkListener
         }
     }
 
+    // Start (but we might not be connected yet).
     public final synchronized void start() throws MuleException
     {
         if (isInitialStateStopped())
@@ -404,100 +409,101 @@ public abstract class AbstractConnector implements Connector, WorkListener
             return;
         }
 
-        lifecycleManager.fireStartPhase(new LifecycleCallback<Connector>()
+        if (!isConnected())
         {
-            public void onTransition(String phaseName, Connector object) throws MuleException
+            try
             {
-
-
-                if (!isConnected())
-                {
-                    startOnConnect = true;
-
-                    // Make sure we are connected
-                    try
-                    {
-                        connect();
-                    }
-                    catch (Exception e)
-                    {
-                        throw new LifecycleException(e, this);
-                    }
-                }
-                else
-                {
-                    //Do start called in this method
-                    startAfterConnect();
-                }
+                // startAfterConnect() will get called from the connect() method once connected.
+                // This is necessary for reconnection strategies.
+                startOnConnect = true;
+                connect();
             }
-        });
-
+            catch (MuleException me)
+            {
+                throw me;
+            }
+            catch (Exception e)
+            {
+                throw new ConnectException(e, this);
+            }
+        }
+        else
+        {        
+            startAfterConnect();
+        }
     }
 
+    // Start now that we're sure we're connected.
     protected synchronized void startAfterConnect() throws MuleException
     {
+        // Reset this flag if it was set
+        startOnConnect = false;
+        
+        // This breaks ConnectorLifecycleTestCase.testDoubleStartConnector()
+        //if (isStarted())
+        //{
+        //    return;
+        //}
+        
         if (logger.isInfoEnabled())
         {
             logger.info("Starting: " + this);
         }
 
-        // the scheduler is recreated after stop()
-        scheduler = createScheduler();
-
-        try
+        lifecycleManager.fireStartPhase(new LifecycleCallback<Connector>()
         {
-            initWorkManagers();
-        }
-        catch (MuleException e)
-        {
-            throw new InitialisationException(e, this);
-        }
-
-        if (!isStarted())
-        {
-            doStart();
-        }
-
-        if (receivers != null)
-        {
-            for (MessageReceiver receiver : receivers.values())
+            public void onTransition(String phaseName, Connector object) throws MuleException
             {
-                final List<MuleException> errors = new ArrayList<MuleException>();
-                try
+                initWorkManagers();        
+                scheduler = createScheduler();
+                doStart();
+                
+                if (receivers != null)
                 {
-                    if (logger.isDebugEnabled())
+                    for (MessageReceiver receiver : receivers.values())
                     {
-                        logger.debug("Starting receiver on endpoint: "
-                                + receiver.getEndpoint().getEndpointURI());
-                    }
-                    if (receiver.getFlowConstruct().getLifecycleState().isStarted())
-                    {
-                        receiver.start();
-                    }
-                }
-                catch (MuleException e)
-                {
-                    logger.error(e);
-                    errors.add(e);
-                }
+                        final List<MuleException> errors = new ArrayList<MuleException>();
+                        try
+                        {
+                            if (logger.isDebugEnabled())
+                            {
+                                logger.debug("Starting receiver on endpoint: "
+                                        + receiver.getEndpoint().getEndpointURI());
+                            }
+                            if (receiver.getFlowConstruct().getLifecycleState().isStarted())
+                            {
+                                receiver.start();
+                            }
+                        }
+                        catch (MuleException e)
+                        {
+                            logger.error(e);
+                            errors.add(e);
+                        }
 
-                if (!errors.isEmpty())
-                {
-                    // throw the first one in order not to break the reconnection
-                    // strategy logic,
-                    // every exception has been logged above already
-                    // api needs refactoring to support the multi-cause exception
-                    // here
-                    throw errors.get(0);
-                }
+                        if (!errors.isEmpty())
+                        {
+                            // throw the first one in order not to break the reconnection
+                            // strategy logic,
+                            // every exception has been logged above already
+                            // api needs refactoring to support the multi-cause exception
+                            // here
+                            throw errors.get(0);
+                        }
+                    }
+                }                
             }
-        }
-
+        });
     }
 
-
     public final synchronized void stop() throws MuleException
     {
+        // This breaks ConnectorLifecycleTestCase.testDoubleStopConnector()
+        //if (isStopped() || isStopping())
+        //{
+        //    return;
+        //}
+        
         lifecycleManager.fireStopPhase(new LifecycleCallback<Connector>()
         {
             public void onTransition(String phaseName, Connector object) throws MuleException
@@ -507,8 +513,7 @@ public abstract class AbstractConnector implements Connector, WorkListener
 
                 doStop();
 
-                // Stop all the receivers on this connector (this will cause them to
-                // disconnect too)
+                // Stop all the receivers on this connector
                 if (receivers != null)
                 {
                     for (MessageReceiver receiver : receivers.values())
@@ -521,6 +526,8 @@ public abstract class AbstractConnector implements Connector, WorkListener
                     }
                 }
 
+                // TODO We shouldn't need to automatically disconnect just because we're stopping, these are 
+                // discrete stages in the connector's lifecycle.  
                 if (isConnected())
                 {
                     try
@@ -554,10 +561,22 @@ public abstract class AbstractConnector implements Connector, WorkListener
     {
         try
         {
-            if (lifecycleManager.getState().isStarted())
+            if (isStarted())
             {
                 stop();
             }
+            if (isConnected())
+            {
+                disconnect();
+            }
+        }
+        catch (Exception e)
+        {
+            logger.warn(e.getMessage(), e);
+        }
+        
+        try
+        {
             lifecycleManager.fireDisposePhase(new LifecycleCallback<Connector>()
             {
                 public void onTransition(String phaseName, Connector object) throws MuleException
@@ -569,7 +588,7 @@ public abstract class AbstractConnector implements Connector, WorkListener
         }
         catch (MuleException e)
         {
-            logger.warn("Failed to dispose connector: " + name, e);
+            logger.warn(e.getMessage(), e);
         }
     }
 
@@ -578,6 +597,11 @@ public abstract class AbstractConnector implements Connector, WorkListener
         return lifecycleManager.getState().isStarted();
     }
 
+    public final boolean isStarting()
+    {
+        return lifecycleManager.getState().isStarting();
+    }
+
     public boolean isInitialised()
     {
         return lifecycleManager.getState().isInitialised();
@@ -588,6 +612,11 @@ public abstract class AbstractConnector implements Connector, WorkListener
         return lifecycleManager.getState().isStopped();
     }
 
+    public boolean isStopping()
+    {
+        return lifecycleManager.getState().isStopping();
+    }
+
 
     //-----------------------------------------------------------------------------------------------//
     //-             END LIFECYCLE METHODS
@@ -1273,15 +1302,7 @@ public abstract class AbstractConnector implements Connector, WorkListener
             MessageReceiver receiver = receivers.remove(getReceiverKey(flowConstruct, endpoint));
             if (receiver != null)
             {
-                if (isConnected())
-                {
-                    receiver.disconnect();
-                }
-
-                if (isStarted())
-                {
-                    receiver.stop();
-                }
+                // This will automatically stop and disconnect before disposing.
                 destroyReceiver(receiver, endpoint);
                 doUnregisterListener(flowConstruct, endpoint, receiver);
             }
@@ -1540,11 +1561,42 @@ public abstract class AbstractConnector implements Connector, WorkListener
                     }
                 }
                 doConnect();
+
+                if (receivers != null)
+                {
+                    for (MessageReceiver receiver : receivers.values())
+                    {
+                        final List<MuleException> errors = new ArrayList<MuleException>();
+                        try
+                        {
+                            if (logger.isDebugEnabled())
+                            {
+                                logger.debug("Connecting receiver on endpoint: " + receiver.getEndpoint().getEndpointURI());
+                            }
+                            receiver.connect();
+                        }
+                        catch (MuleException e)
+                        {
+                            logger.error(e);
+                            errors.add(e);
+                        }
+
+                        if (!errors.isEmpty())
+                        {
+                            // throw the first one in order not to break the reconnection
+                            // strategy logic,
+                            // every exception has been logged above already
+                            // api needs refactoring to support the multi-cause exception
+                            // here
+                            throw errors.get(0);
+                        }
+                    }
+                }
+                
                 setConnected(true);
-
                 logger.info("Connected: " + getWorkDescription());
-
-                if (startOnConnect)
+                
+                if (startOnConnect && !isStarted() && !isStarting())
                 {
                     startAfterConnect();
                 }
@@ -1578,50 +1630,47 @@ public abstract class AbstractConnector implements Connector, WorkListener
     {
         startOnConnect = isStarted();
 
-        try
+        if (receivers != null)
         {
-            if (receivers != null)
+            for (MessageReceiver receiver : receivers.values())
             {
-                for (MessageReceiver receiver : receivers.values())
+                if (logger.isDebugEnabled())
+                {
+                    logger.debug("Disconnecting receiver on endpoint: "
+                            + receiver.getEndpoint().getEndpointURI());
+                }
+                try
                 {
-                    if (logger.isDebugEnabled())
-                    {
-                        logger.debug("Disconnecting receiver on endpoint: "
-                                + receiver.getEndpoint().getEndpointURI());
-                    }
                     receiver.disconnect();
                 }
+                catch (Exception e)
+                {
+                    logger.error(e.getMessage(), e);
+                }                
             }
-            this.doDisconnect();
         }
+        try
+        {
+	        if (isStarted() && !isStopping())
+    	    {
+        	    stop();
+	        }
+            this.doDisconnect();
+            if (logger.isInfoEnabled())
+            {
+                logger.info("Disconnected: " + this.getConnectionDescription());
+            }
+            this.fireNotification(new ConnectionNotification(this, getConnectEventId(),
+                    ConnectionNotification.CONNECTION_DISCONNECTED));
+        }
+        catch (Exception e)
+        {
+            logger.error(e.getMessage());
+        }                
         finally
         {
-            if (receivers != null)
-            {
-                for (MessageReceiver receiver : receivers.values())
-                {
-                    // TODO MULE-3969
-                    if (receiver instanceof AbstractMessageReceiver
-                            && ((AbstractMessageReceiver) receiver).isStarted())
-                    {
-                        if (logger.isDebugEnabled())
-                        {
-                            logger.debug("Stopping receiver on endpoint: "
-                                    + receiver.getEndpoint().getEndpointURI());
-                        }
-                        receiver.stop();
-                    }
-                }
-            }
+            connected.set(false);
         }
-
-        connected.set(false);
-        if (logger.isInfoEnabled())
-        {
-            logger.info("Disconnected: " + this.getConnectionDescription());
-        }
-        this.fireNotification(new ConnectionNotification(this, getConnectEventId(),
-                ConnectionNotification.CONNECTION_DISCONNECTED));
     }
 
     public String getConnectionDescription()
@@ -1639,6 +1688,16 @@ public abstract class AbstractConnector implements Connector, WorkListener
         connected.set(flag);
     }
 
+    public final void setReconnecting(boolean flag)
+    {
+        reconnecting.set(flag);
+    }
+
+    public final boolean isReconnecting()
+    {
+        return reconnecting.get();
+    }
+
     /**
      * Template method where any connections should be made for the connector
      *
@@ -2390,6 +2449,7 @@ public abstract class AbstractConnector implements Connector, WorkListener
         else
         {
             DefaultMessageProcessorChainBuilder builder = new DefaultMessageProcessorChainBuilder();
+            builder.setName("dispatcher processor chain for '" + endpoint.getAddress() + "'");
             builder.chain(new OptionalAsyncInterceptingMessageProcessor(new WorkManagerSource()
             {
                 public WorkManager getWorkManager() throws MuleException
