@@ -1,5 +1,5 @@
 /*
- * $Id: AbstractReceivingMailConnectorTestCase.java 19873 2010-10-08 23:54:59Z dzapata $
+ * $Id: AbstractReceivingMailConnectorTestCase.java 20385 2010-11-29 20:25:26Z dfeist $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -68,7 +68,7 @@ public abstract class AbstractReceivingMailConnectorTestCase extends AbstractMai
         });
 
         Service service = MuleTestUtils.getTestService(uniqueName("testComponent"), FunctionalTestComponent.class, props, muleContext, /*initialize*/false);
-        EndpointBuilder eb = muleContext.getRegistry().lookupEndpointFactory().getEndpointBuilder(getTestEndpointURI());
+        EndpointBuilder eb = muleContext.getEndpointFactory().getEndpointBuilder(getTestEndpointURI());
         eb.setDisableTransportTransformer(true);
         InboundEndpoint ep = eb.buildInboundEndpoint();
         ((CompositeMessageSource) service.getMessageSource()).addSource(ep);
