@@ -1,5 +1,5 @@
 /*
- * $Id: FtpFunctionalTestCase.java 20321 2010-11-24 15:21:24Z dfeist $
+ * $Id: FtpFunctionalTestCase.java 21147 2011-01-28 03:18:51Z dzapata $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -22,26 +22,11 @@ import edu.emory.mathcs.backport.java.util.concurrent.atomic.AtomicReference;
 
 public class FtpFunctionalTestCase extends AbstractFtpServerTestCase
 {
-    private static int PORT = 60198;
-
-    public FtpFunctionalTestCase()
-    {
-        super(PORT);
-    }
-
     protected String getConfigResources()
     {
         return "ftp-functional-test.xml";
     }
-
-    /**
-     * Used by subclasses (in EE)
-     */
-    public int getPort()
-    {
-        return PORT;
-    }
-    
+   
     public void testSendAndRequest() throws Exception
     {
         CountDownLatch latch = new CountDownLatch(1);
