@@ -1,5 +1,5 @@
 /*
- * $Id: JettyHttpConnector.java 20413 2010-12-01 01:50:19Z dandiep $
+ * $Id: JettyHttpConnector.java 21271 2011-02-14 14:48:06Z aperepel $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -29,10 +29,14 @@ import org.mule.transport.AbstractConnector;
 import org.mule.transport.servlet.JarResourceServlet;
 import org.mule.transport.servlet.MuleReceiverServlet;
 import org.mule.transport.servlet.MuleServletContextListener;
+import org.mule.util.ClassUtils;
 import org.mule.util.IOUtils;
+import org.mule.util.StringMessageUtils;
 import org.mule.util.StringUtils;
 
+import java.io.File;
 import java.io.InputStream;
+import java.net.URL;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
@@ -40,14 +44,16 @@ import java.util.List;
 import javax.servlet.Servlet;
 import javax.servlet.http.HttpServlet;
 
-import edu.emory.mathcs.backport.java.util.Arrays;
-
 import org.mortbay.jetty.Connector;
+import org.mortbay.jetty.Handler;
 import org.mortbay.jetty.Server;
+import org.mortbay.jetty.annotations.Configuration;
 import org.mortbay.jetty.handler.ContextHandlerCollection;
 import org.mortbay.jetty.nio.SelectChannelConnector;
 import org.mortbay.jetty.servlet.Context;
 import org.mortbay.jetty.servlet.ServletHolder;
+import org.mortbay.jetty.webapp.WebAppContext;
+import org.mortbay.jetty.webapp.WebInfConfiguration;
 import org.mortbay.xml.XmlConfiguration;
 
 /**
@@ -93,23 +99,74 @@ public class JettyHttpConnector extends AbstractConnector
     @Override
     protected void doInitialise() throws InitialisationException
     {
-        httpServer = new Server();
+        httpServer = new Server()
+        {
+            @Override
+            public void addHandler(Handler handler)
+            {
+                final Connector c = getServer().getConnectors()[0];
+                if (handler instanceof WebAppContext)
+                {
+                    final WebAppContext webapp = (WebAppContext) handler;
+                    final String msg = String.format("Will deploy a web app at %s:/%s%s%s",
+                                                     "http", c.getHost(),
+                                                     c.getPort() == 80 ? StringUtils.EMPTY : ":" + c.getPort(),
+                                                     webapp.getContextPath());
+
+                    final File workDir = new File(muleContext.getConfiguration().getWorkingDirectory(),
+                                                  "_exploded_wars" + webapp.getContextPath());
+                    workDir.mkdirs();
+                    webapp.setTempDirectory(workDir);
+                    // TODO extract to a better constant
+                    webapp.setAttribute("muleContext", muleContext);
+
+                    if (logger.isInfoEnabled())
+                    {
+                        logger.info(StringMessageUtils.getBoilerPlate(msg, '*', 70));
+                    }
+                }
+                super.addHandler(handler);
+            }
+        };
         
         if (webappsConfiguration != null)
         {
             deployer = new WebAppDeployer();
-            deployer.setWebAppDir(webappsConfiguration.getDirectory());
+            String webAppDir = webappsConfiguration.getDirectory();
+            if (StringUtils.isBlank(webAppDir))
+            {
+                // if none specified, resolve defaults dynamically
+                final String appDir = muleContext.getRegistry().get(MuleProperties.APP_HOME_DIRECTORY_PROPERTY);
+                webAppDir = appDir + "/webapps";
+            }
+
+            if (configFile == null)
+            {
+                // override only if user hasn't specified one (turn off file-mapped buffer for
+                // static files to avoid resource locking, makes webapp resources editable on the fly)
+                final URL muleDefaults = ClassUtils.getResource("org/mule/transport/jetty/webdefault.xml", getClass());
+                deployer.setDefaultsDescriptor(muleDefaults.toExternalForm());
+            }
+            deployer.setWebAppDir(webAppDir);
             deployer.setExtract(true);
             deployer.setParentLoaderPriority(false);
             deployer.setServerClasses(webappsConfiguration.getServerClasses());
             deployer.setSystemClasses(webappsConfiguration.getSystemClasses());
 
-            org.mortbay.jetty.AbstractConnector connector = createJettyConnector();
-            connector.setHost(webappsConfiguration.getHost());
-            connector.setPort(webappsConfiguration.getPort());
+            org.mortbay.jetty.AbstractConnector jettyConnector = createJettyConnector();
+            jettyConnector.setHost(webappsConfiguration.getHost());
+            jettyConnector.setPort(webappsConfiguration.getPort());
             deployer.setContexts(httpServer);
+            String[] confClasses = new String[]
+            {
+                // configures webapp's classloader as a child of a Mule app classloader
+                WebInfConfiguration.class.getName(),
+                // just to get jetty going, we don't need java ee bindings. inherits annotation processing
+                DummyJndiConfiguration.class.getName()
+            };
+            deployer.setConfigurationClasses(confClasses);
 
-            httpServer.addConnector(connector);
+            httpServer.addConnector(jettyConnector);
             httpServer.addLifeCycle(deployer);
         }
         
@@ -127,6 +184,12 @@ public class JettyHttpConnector extends AbstractConnector
                         try
                         {
                             start();
+                            // update the agent displaying webapp urls to the user
+                            final JettyWebappServerAgent agent = (JettyWebappServerAgent) muleContext.getRegistry().lookupAgent(JettyWebappServerAgent.NAME);
+                            if (agent != null)
+                            {
+                                agent.onJettyConnectorStarted(JettyHttpConnector.this);
+                            }
                         }
                         catch (MuleException e)
                         {
@@ -145,32 +208,33 @@ public class JettyHttpConnector extends AbstractConnector
     @SuppressWarnings("unchecked")
     protected void initialiseFromConfigFile() throws InitialisationException
     {
-        if (configFile != null)
+        if (configFile == null)
         {
-            try
-            {
-                InputStream is = IOUtils.getResourceAsStream(configFile, getClass());
-                XmlConfiguration config = new XmlConfiguration(is);
+            return;
+        }
+        try
+        {
+            InputStream is = IOUtils.getResourceAsStream(configFile, getClass());
+            XmlConfiguration config = new XmlConfiguration(is);
 
-                String appHome =
-                    muleContext.getRegistry().lookupObject(MuleProperties.APP_HOME_DIRECTORY_PROPERTY);
-                if (appHome == null)
-                {
-                    // Mule IDE sets app.home as part of the launch config it creates
-                    appHome = System.getProperty(MuleProperties.APP_HOME_DIRECTORY_PROPERTY);
-                }
-
-                if (appHome != null)
-                {
-                    config.getProperties().put(MuleProperties.APP_HOME_DIRECTORY_PROPERTY, appHome);
-                }
-                
-                config.configure(httpServer);
-            }
-            catch (Exception e)
+            String appHome =
+                muleContext.getRegistry().lookupObject(MuleProperties.APP_HOME_DIRECTORY_PROPERTY);
+            if (appHome == null)
             {
-                throw new InitialisationException(e, this);
+                // Mule IDE sets app.home as part of the launch config it creates
+                appHome = System.getProperty(MuleProperties.APP_HOME_DIRECTORY_PROPERTY);
             }
+
+            if (appHome != null)
+            {
+                config.getProperties().put(MuleProperties.APP_HOME_DIRECTORY_PROPERTY, appHome);
+            }
+
+            config.configure(httpServer);
+        }
+        catch (Exception e)
+        {
+            throw new InitialisationException(e, this);
         }
     }
 
@@ -495,4 +559,35 @@ public class JettyHttpConnector extends AbstractConnector
     {
         this.webappsConfiguration = webappsConfiguration;
     }
+
+    /**
+     * A helper method to differentiate between jetty-based connectors which can host full wars and ones which can't.
+     */
+    public boolean canHostFullWars()
+    {
+        return true;
+    }
+
+    /**
+     * A helper class to let jetty startup, we don't bind java ee objects like java:comp/UserTransaction.
+     */
+    public static class DummyJndiConfiguration extends Configuration
+    {
+
+        public DummyJndiConfiguration() throws ClassNotFoundException
+        {
+        }
+
+        @Override
+        public void bindUserTransaction() throws Exception
+        {
+            // no-op
+        }
+
+        @Override
+        protected void lockCompEnv() throws Exception
+        {
+            // no-op
+        }
+    }
 }
