@@ -1,5 +1,5 @@
 /*
- * $Id: MultipleNamedTcpConnectorsTestCase.java 19191 2010-08-25 21:05:23Z tcarlson $
+ * $Id: MultipleNamedTcpConnectorsTestCase.java 20297 2010-11-22 18:49:18Z aperepel $
  * --------------------------------------------------------------------------------------
  * Copyright (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
  *
@@ -10,9 +10,9 @@
 
 package org.mule.transport.tcp;
 
-import org.mule.tck.FunctionalTestCase;
+import org.mule.tck.DynamicPortTestCase;
 
-public class MultipleNamedTcpConnectorsTestCase extends FunctionalTestCase
+public class MultipleNamedTcpConnectorsTestCase extends DynamicPortTestCase
 {
     protected String getConfigResources()
     {
@@ -23,5 +23,11 @@ public class MultipleNamedTcpConnectorsTestCase extends FunctionalTestCase
     {
         // no-op, the initialization must not fail.
     }
+
+    @Override
+    protected int getNumPortsToFind()
+    {
+        return 1;
+    }
 }
 
